[![Build Status](https://travis-ci.org/laerteallan/apm-agent-python-tornado.svg?branch=master)](https://travis-ci.org/laerteallan/apm-agent-python-tornado)
[![Coverage Status](https://coveralls.io/repos/github/laerteallan/apm-agent-python-tornado/badge.svg?branch=master)](https://coveralls.io/github/laerteallan/apm-agent-python-tornado?branch=master)
[![Requirements Status](https://requires.io/github/laerteallan/apm-agent-python-tornado/requirements.svg?branch=master)](https://requires.io/github/laerteallan/apm-agent-python-tornado/requirements/?branch=master)

# Tornado apm -- Elastic APM agent for python/tornado  

This project has integrated with apm-agent of company Elastic Search. It 


### Prerequisites

- Agent apm of elastic search
- Tornado framework
- python 3.+

### Installing
- pip install  elastic-apm
- pip install tornado
- python setup install

### Execute test

- make tests

### Usage

>The [main.py](main.py) file show a implmentation

## Authors

* **Laerte Allan** - *Initial work* - [laerteallan](https://github.com/laerteallan)
